# lib4cv
useful library for computer vision

## comm

io_utils: read image, save image, preprocess image

## DeomoFaceMorph

## detection
face detection based on SFD, DLIB, and [RetinaFace][1], and [FaceBoxes][2]

Uages:

    from libcv import facedetect
    

## pytorch

## example

[1]: https://github.com/JPlin/face-detection
[2]: https://github.com/cleardusk/3DDFA_V2/tree/master/FaceBoxes